==> SnappEmailApiClient-0.3.8.zip: SnappEmailApiClient-0.3.8/snapp_email/endpoints/action/ActionDeleteQuestion_18Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import ActionDeleteQuestion_18
from snapp_email.datacontract.utils import export_dict, fill


class ActionDeleteQuestion_18Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, accept_type=None):
        """
        Retrieve options available for resource 'ActionDeleteQuestion_18'.
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ActionDeleteQuestion_18
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'action'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.action.delete.question-v5.8+json',
            'Accept': 'application/vnd.4thoffice.action.delete.question-v5.8+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers)
        
        return fill(ActionDeleteQuestion_18, response.json())
    
    def create(self, obj, accept_type=None):
        """
        Delete notification about question on arbitrary resource.
        
        :param obj: Object to be persisted
        :type obj: ActionDeleteQuestion_18
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ActionDeleteQuestion_18
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'action'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.action.delete.question-v5.8+json',
            'Accept': 'application/vnd.4thoffice.action.delete.question-v5.8+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('post', endpoint, url_parameters, add_headers, data=json.dumps(data))
        
        return fill(ActionDeleteQuestion_18, response.json())

==> SnappEmailApiClient-0.3.14.zip: SnappEmailApiClient-0.3.14/snapp_email/endpoints/action/ActionDeleteQuestion_18Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import ActionDeleteQuestion_18
from snapp_email.datacontract.utils import export_dict, fill


class ActionDeleteQuestion_18Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'ActionDeleteQuestion_18'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ActionDeleteQuestion_18
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'action'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.action.delete.question-v5.8+json',
            'Accept': 'application/vnd.4thoffice.action.delete.question-v5.8+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(ActionDeleteQuestion_18, response.json())
    
    def create(self, obj, impersonate_user_id=None, accept_type=None):
        """
        Delete notification about question on arbitrary resource.
        
        :param obj: Object to be persisted
        :type obj: ActionDeleteQuestion_18
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ActionDeleteQuestion_18
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'action'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.action.delete.question-v5.8+json',
            'Accept': 'application/vnd.4thoffice.action.delete.question-v5.8+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('post', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id, data=json.dumps(data))
        
        return fill(ActionDeleteQuestion_18, response.json())
